==> inspect_ai-0.3.63-py3-none-any.whl: inspect_ai/_view/www/src/samples/chat/tools/ToolCallView.tsx <==
import ExpandablePanel from "../../../components/ExpandablePanel";
import { ContentTool } from "../../../types";
import {
  ContentAudio,
  ContentImage,
  ContentText,
  ContentVideo,
  ToolCallContent,
} from "../../../types/log";
import { MessageContent } from "../MessageContent";
import { ToolInput } from "./ToolInput";
import { ToolTitle } from "./ToolTitle";

interface ToolCallViewProps {
  functionCall: string;
  input?: string;
  inputType?: string;
  view?: ToolCallContent;
  output:
    | string
    | number
    | boolean
    | ContentText
    | ContentAudio
    | ContentImage
    | ContentVideo
    | ContentTool
    | (
        | ContentText
        | ContentAudio
        | ContentImage
        | ContentVideo
        | ContentTool
      )[];
  mode?: "compact";
}

/**
 * Renders the ToolCallView component.
 */
export const ToolCallView: React.FC<ToolCallViewProps> = ({
  functionCall,
  input,
  inputType,
  view,
  output,
  mode,
}) => {
  // don't collapse if output includes an image
  function isContentImage(
    value:
      | string
      | number
      | boolean
      | ContentText
      | ContentAudio
      | ContentImage
      | ContentVideo
      | ContentTool,
  ) {
    if (value && typeof value === "object") {
      if (value.type === "image") {
        return true;
      } else if (value.type === "tool") {
        if (
          Array.isArray(value.content) &&
          value.content.some(isContentImage)
        ) {
          return true;
        }
      }
    }
    return false;
  }

  const collapse = Array.isArray(output)
    ? output.every((item) => !isContentImage(item))
    : !isContentImage(output);

  return (
    <div>
      {mode !== "compact" && (!view || view.title) ? (
        <ToolTitle title={view?.title || functionCall} />
      ) : (
        ""
      )}
      <div>
        <div>
          <ToolInput type={inputType} contents={input} view={view} />
          {output ? (
            <ExpandablePanel collapse={collapse} border={true} lines={15}>
              <MessageContent contents={normalizeContent(output)} />
            </ExpandablePanel>
          ) : (
            ""
          )}
        </div>
      </div>
    </div>
  );
};

/**
 * Renders the ToolCallView component.
 */
const normalizeContent = (
  output:
    | string
    | number
    | boolean
    | ContentText
    | ContentImage
    | ContentAudio
    | ContentVideo
    | ContentTool
    | (
        | ContentText
        | ContentImage
        | ContentAudio
        | ContentVideo
        | ContentTool
      )[],
): (
  | ContentText
  | ContentImage
  | ContentAudio
  | ContentVideo
  | ContentTool
)[] => {
  if (Array.isArray(output)) {
    return output;
  } else {
    return [
      {
        type: "tool",
        content: [
          {
            type: "text",
            text: String(output),
          },
        ],
      },
    ];
  }
};

==> inspect_ai-0.3.69-py3-none-any.whl: inspect_ai/_view/www/src/samples/chat/tools/ToolCallView.tsx <==
import { useMemo } from "react";
import ExpandablePanel from "../../../components/ExpandablePanel";
import { ContentTool } from "../../../types";
import {
  ContentAudio,
  ContentImage,
  ContentText,
  ContentVideo,
  ToolCallContent,
} from "../../../types/log";
import { MessageContent } from "../MessageContent";
import { ToolInput } from "./ToolInput";
import { ToolTitle } from "./ToolTitle";

interface ToolCallViewProps {
  functionCall: string;
  input?: string;
  highlightLanguage?: string;
  view?: ToolCallContent;
  output:
    | string
    | number
    | boolean
    | ContentText
    | ContentAudio
    | ContentImage
    | ContentVideo
    | ContentTool
    | (
        | ContentText
        | ContentAudio
        | ContentImage
        | ContentVideo
        | ContentTool
      )[];
  mode?: "compact";
}

/**
 * Renders the ToolCallView component.
 */
export const ToolCallView: React.FC<ToolCallViewProps> = ({
  functionCall,
  input,
  highlightLanguage,
  view,
  output,
  mode,
}) => {
  // don't collapse if output includes an image
  function isContentImage(
    value:
      | string
      | number
      | boolean
      | ContentText
      | ContentAudio
      | ContentImage
      | ContentVideo
      | ContentTool,
  ) {
    if (value && typeof value === "object") {
      if (value.type === "image") {
        return true;
      } else if (value.type === "tool") {
        if (
          Array.isArray(value.content) &&
          value.content.some(isContentImage)
        ) {
          return true;
        }
      }
    }
    return false;
  }

  const collapse = Array.isArray(output)
    ? output.every((item) => !isContentImage(item))
    : !isContentImage(output);
  const normalizedContent = useMemo(() => normalizeContent(output), [output]);

  return (
    <div>
      {mode !== "compact" && (!view || view.title) ? (
        <ToolTitle title={view?.title || functionCall} />
      ) : (
        ""
      )}
      <div>
        <div>
          <ToolInput
            highlightLanguage={highlightLanguage}
            contents={input}
            toolCallView={view}
          />
          <ExpandablePanel collapse={collapse} border={true} lines={15}>
            <MessageContent contents={normalizedContent} />
          </ExpandablePanel>
        </div>
      </div>
    </div>
  );
};

/**
 * Renders the ToolCallView component.
 */
const normalizeContent = (
  output:
    | string
    | number
    | boolean
    | ContentText
    | ContentImage
    | ContentAudio
    | ContentVideo
    | ContentTool
    | (
        | ContentText
        | ContentImage
        | ContentAudio
        | ContentVideo
        | ContentTool
      )[],
): (
  | ContentText
  | ContentImage
  | ContentAudio
  | ContentVideo
  | ContentTool
)[] => {
  if (Array.isArray(output)) {
    return output;
  } else {
    return [
      {
        type: "tool",
        content: [
          {
            type: "text",
            text: String(output),
          },
        ],
      },
    ];
  }
};
